@@ -2,7 +2,7 @@ import { DataSourcePlugin } from '@grafana/data';
 import Datasource from './datasource';
 
 import LokiCheatSheet from './components/LokiCheatSheet';
-import LokiQueryField from './components/LokiQueryField';
+import LokiExploreQueryEditor from './components/LokiExploreQueryEditor';
 import LokiQueryEditor from './components/LokiQueryEditor';
 import { LokiAnnotationsQueryCtrl } from './LokiAnnotationsQueryCtrl';
 import { ConfigEditor } from './configuration/ConfigEditor';
@@ -10,6 +10,6 @@ import { ConfigEditor } from './configuration/ConfigEditor';
 export const plugin = new DataSourcePlugin(Datasource)
   .setQueryEditor(LokiQueryEditor)
   .setConfigEditor(ConfigEditor)
-  .setExploreQueryField(LokiQueryField)
+  .setExploreQueryField(LokiExploreQueryEditor)
   .setExploreStartPage(LokiCheatSheet)
   .setAnnotationQueryCtrl(LokiAnnotationsQueryCtrl);
